==> selenium-remote-driver-4.19.1.jar: module-info.java <==
module org.seleniumhq.selenium.remote_driver {
    /* static phase */ requires io.opentelemetry.sdk;
    /* static phase */ requires io.opentelemetry.sdk.autoconfigure;
    /* static phase */ requires io.opentelemetry.sdk.autoconfigure.spi;
    /* static phase */ requires io.opentelemetry.sdk.common;
    /* static phase */ requires io.opentelemetry.semconv;
    /* static phase */ requires net.bytebuddy;
    /* transitive */ /* static phase */ requires io.opentelemetry.api;
    /* transitive */ /* static phase */ requires io.opentelemetry.context;
    /* transitive */ /* static phase */ requires io.opentelemetry.sdk.trace;
    /* transitive */ requires java.logging;
    /* transitive */ requires org.seleniumhq.selenium.api;
    /* transitive */ requires org.seleniumhq.selenium.http;
    /* transitive */ requires org.seleniumhq.selenium.json;
    /* transitive */ requires org.seleniumhq.selenium.manager;
    /* transitive */ requires org.seleniumhq.selenium.os;

    exports org.openqa.selenium.bidi;
    exports org.openqa.selenium.bidi.browsingcontext;
    exports org.openqa.selenium.bidi.log;
    exports org.openqa.selenium.bidi.module;
    exports org.openqa.selenium.bidi.network;
    exports org.openqa.selenium.bidi.script;
    exports org.openqa.selenium.bidi.storage;
    exports org.openqa.selenium.concurrent;
    exports org.openqa.selenium.devtools;
    exports org.openqa.selenium.devtools.events;
    exports org.openqa.selenium.devtools.idealized;
    exports org.openqa.selenium.devtools.idealized.browser.model;
    exports org.openqa.selenium.devtools.idealized.log;
    exports org.openqa.selenium.devtools.idealized.log.model;
    exports org.openqa.selenium.devtools.idealized.runtime.model;
    exports org.openqa.selenium.devtools.idealized.target;
    exports org.openqa.selenium.devtools.idealized.target.model;
    exports org.openqa.selenium.devtools.noop;
    exports org.openqa.selenium.remote;
    exports org.openqa.selenium.remote.codec;
    exports org.openqa.selenium.remote.codec.w3c;
    exports org.openqa.selenium.remote.html5;
    exports org.openqa.selenium.remote.locators;
    exports org.openqa.selenium.remote.mobile;
    exports org.openqa.selenium.remote.service;
    exports org.openqa.selenium.remote.tracing;
    exports org.openqa.selenium.remote.tracing.empty;
    exports org.openqa.selenium.remote.tracing.opentelemetry;
    exports org.openqa.selenium.support.decorators;

    opens org.openqa.selenium.devtools.idealized.log to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.service to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.bidi.storage to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.bidi.log to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.codec to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.idealized.target to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.idealized.target.model to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.tracing.empty to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.bidi to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.mobile to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.tracing to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.concurrent to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.idealized to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.locators to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.html5 to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.bidi.module to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.bidi.browsingcontext to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.support.decorators to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.bidi.network to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.idealized.browser.model to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.idealized.runtime.model to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.bidi.script to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.events to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.noop to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.idealized.log.model to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.codec.w3c to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.tracing.opentelemetry to org.seleniumhq.selenium.json;

    provides AugmenterProvider with BiDiProvider, DevToolsProvider;

}

==> selenium-remote-driver-4.28.0.jar: module-info.java <==
module org.seleniumhq.selenium.remote_driver {
    /* static phase */ requires io.opentelemetry.sdk;
    /* static phase */ requires io.opentelemetry.sdk.autoconfigure;
    /* static phase */ requires io.opentelemetry.sdk.autoconfigure.spi;
    /* static phase */ requires io.opentelemetry.sdk.common;
    /* static phase */ requires io.opentelemetry.semconv;
    /* static phase */ requires net.bytebuddy;
    requires org.seleniumhq.selenium.manager;
    /* transitive */ /* static phase */ requires io.opentelemetry.api;
    /* transitive */ /* static phase */ requires io.opentelemetry.context;
    /* transitive */ /* static phase */ requires io.opentelemetry.sdk.trace;
    /* transitive */ requires java.logging;
    /* transitive */ requires org.seleniumhq.selenium.api;
    /* transitive */ requires org.seleniumhq.selenium.http;
    /* transitive */ requires org.seleniumhq.selenium.json;
    /* transitive */ requires org.seleniumhq.selenium.os;

    exports org.openqa.selenium.bidi;
    exports org.openqa.selenium.bidi.browsingcontext;
    exports org.openqa.selenium.bidi.log;
    exports org.openqa.selenium.bidi.module;
    exports org.openqa.selenium.bidi.network;
    exports org.openqa.selenium.bidi.script;
    exports org.openqa.selenium.bidi.storage;
    exports org.openqa.selenium.concurrent;
    exports org.openqa.selenium.devtools;
    exports org.openqa.selenium.devtools.events;
    exports org.openqa.selenium.devtools.idealized;
    exports org.openqa.selenium.devtools.idealized.browser.model;
    exports org.openqa.selenium.devtools.idealized.log;
    exports org.openqa.selenium.devtools.idealized.log.model;
    exports org.openqa.selenium.devtools.idealized.runtime.model;
    exports org.openqa.selenium.devtools.idealized.target;
    exports org.openqa.selenium.devtools.idealized.target.model;
    exports org.openqa.selenium.devtools.noop;
    exports org.openqa.selenium.remote;
    exports org.openqa.selenium.remote.codec;
    exports org.openqa.selenium.remote.codec.w3c;
    exports org.openqa.selenium.remote.html5;
    exports org.openqa.selenium.remote.locators;
    exports org.openqa.selenium.remote.mobile;
    exports org.openqa.selenium.remote.service;
    exports org.openqa.selenium.remote.tracing;
    exports org.openqa.selenium.remote.tracing.empty;
    exports org.openqa.selenium.remote.tracing.opentelemetry;
    exports org.openqa.selenium.support.decorators;

    opens org.openqa.selenium.devtools.idealized.log to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.service to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.bidi.storage to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.bidi.log to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.codec to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.idealized.target to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.idealized.target.model to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.tracing.empty to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.bidi to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.mobile to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.tracing to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.concurrent to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.idealized to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.locators to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.html5 to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.bidi.module to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.bidi.browsingcontext to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.support.decorators to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.bidi.network to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.idealized.browser.model to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.idealized.runtime.model to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.bidi.script to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.events to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.noop to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.devtools.idealized.log.model to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.codec.w3c to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.remote.tracing.opentelemetry to org.seleniumhq.selenium.json;

    provides AugmenterProvider with BiDiProvider, DevToolsProvider;

}
